@@ -63,10 +63,11 @@ class PoseTransformer(object):
 
     def __init__(self, req, motorcortex_types):
         self.__MotionSpec = motorcortex_types.getNamespace("motion_spec")
-        if not self.__MotionSpec:
-            path = os.path.dirname(motionSL_pb2.__file__)
-            motorcortex_types.load([{'proto': motionSL_pb2, 'hash': path + '/motionSL_hash.json'}])
+        self.__MotionSpec_v1 = motorcortex_types.getNamespace("motion_spec_v1")
+        if not self.__MotionSpec or not self.__MotionSpec_v1:
+            robot_control.init(motorcortex_types)
             self.__MotionSpec = motorcortex_types.getNamespace("motion_spec")
+            self.__MotionSpec_v1 = motorcortex_types.getNamespace("motion_spec_v1")
 
         self.__motorcortex_types = motorcortex_types
         self.__req = req
@@ -93,7 +94,7 @@ class PoseTransformer(object):
             cart_coord = [0.0, 0.0, 0.0, 0.0, 0.0, 0.0]
         request_id = next(self.__request_id)
         if system_id:
-            cart_to_joint_list_req = self.__MotionSpec.CartToJointListWithId()
+            cart_to_joint_list_req = self.__MotionSpec_v1.CartToJointList()
             cart_to_joint_list_req.system_id = system_id
         else:
             cart_to_joint_list_req = self.__MotionSpec.CartToJointList()
@@ -129,7 +130,7 @@ class PoseTransformer(object):
             cart_coord = [0.0, 0.0, 0.0, 0.0, 0.0, 0.0]
         request_id = next(self.__request_id)
         if system_id:
-            joint_to_cart_list_req = self.__MotionSpec.JointToCartListWithId()
+            joint_to_cart_list_req = self.__MotionSpec_v1.JointToCartList()
             joint_to_cart_list_req.system_id = system_id
         else:
             joint_to_cart_list_req = self.__MotionSpec.JointToCartList()
